import subprocess
import yaml


def load_auth(file_name: str = ".ci-auth.yml"):
    """Load the credentials from a YAML file"""

    with open(file_name, "r") as f:
        pipeline = yaml.safe_load(f)
        return pipeline


def command(command: str):
    """Run Shell Command"""
    result = subprocess.run(command, stdout=subprocess.PIPE, shell=True)
    output = result.stdout.decode("utf-8")
    if result.returncode != 0:
        output = "$ERROR"
    return output



import argparse
from .pipeline import run_pipeline as run
from .gitman import clone, pull


def cli():
    """Command Line Interface"""

    # Parser
    parser = argparse.ArgumentParser()

    # Args
    parser.add_argument("action", help="Options: [run, clone, pull]")
    parser.add_argument("-s", "--stages", help="Stages of the Pipeline you want to run")
    parser.add_argument("-c", "--config", help="Use custom setting's file")

    args = parser.parse_args()

    match args.action:
        case "run":
            run()
        case "clone":
            clone()
        case "pull":
            pull()
